@@ -24,7 +24,7 @@ package Net::Patricia;
 use strict;
 use warnings;
 
-require 5.006_000;
+require 5.008;
 
 use version;
 use Carp;
@@ -38,7 +38,7 @@ BEGIN {
   @EXPORT = qw(AF_INET AF_INET6);
 }
 
-'$Revision: 1.17 $' =~ m/(\d+)\.(\d+)((_\d+)|)/ && ( $VERSION = "$1.$2$3");
+'$Revision: 1.18 $' =~ m/(\d+)\.(\d+)((_\d+)|)/ && ( $VERSION = "$1.$2$3");
 
 bootstrap Net::Patricia $VERSION;
 
@@ -67,9 +67,9 @@ sub _ip_bits {
   my $bits;
 
   if (ref ($self) eq 'Net::Patricia::AF_INET6') { 
-	$bits = ($str =~ s,/(\d+)$,,) ? $1 : 128; 
+	$bits = ($str =~ s|/(\d+)$||) ? $1 : 128; 
   } else { 
-	$bits = ($str =~ s,/(\d+)$,,) ? $1 : 32; 
+	$bits = ($str =~ s|/(\d+)$||) ? $1 : 32; 
   }
   ($str,$bits);
 }
